@@ -46,8 +46,9 @@ class LScli extends LSlog_staticLoggerClass {
    * @param[in] $long_desc          string|false    A long description of what this command does (optional, default: false)
    * @param[in] $need_ldap_con      boolean         Permit to define if this command need connection to LDAP server (optional,
    *                                                default: true)
-   * @param[in] $args_autocompleter callable|null   Allow override if a command already exists with the same name (optional,
-   * @param[in] $override       boolean             Allow override if a command already exists with the same name (optional,
+   * @param[in] $args_autocompleter callable|null   Callable of the CLI command arguments autocompleter (optional, default:
+   *                                                null)
+   * @param[in] $override           boolean         Allow override if a command already exists with the same name (optional,
    *                                                default: false)
    *
    * @retval void
@@ -92,6 +93,7 @@ class LScli extends LSlog_staticLoggerClass {
     echo "  -q|--quiet        Quiet mode: nothing log on console (but keep other logging handler)\n";
     echo "  -d|--debug        Debug mode (set log level to DEBUG, default: WARNING)\n";
     echo "  -v|--verbose      Verbose mode (set log level to INFO, default: WARNING)\n";
+    echo "  --trace           Trace mode (set log level to TRACE, default: WARNING)\n";
     echo "  -C|--console      Log on console with same log level as other handlers (otherwise, log only errors)\n";
     echo "  -S|--ldap-server  Connect to a specific LDAP server: you could specify a LDAP\n";
     echo "                    server by its declaration order in configuration (default:\n";
@@ -160,6 +162,9 @@ class LScli extends LSlog_staticLoggerClass {
           case '--verbose':
             $log_level = 'INFO';
             break;
+          case '--trace':
+            $log_level = 'TRACE';
+            break;
           case '-q':
           case '--quiet':
             $quiet = true;
@@ -398,6 +403,7 @@ class LScli extends LSlog_staticLoggerClass {
       '-h', '--help',
       '-d', '--debug',
       '-v', '--verbose',
+      '--trace',
       '-q', '--quiet',
       '-C', '--console',
       '-S', '--ldap-server',
@@ -770,10 +776,10 @@ class LScli extends LSlog_staticLoggerClass {
  * Error Codes
  */
 LSerror :: defineError('LScli_01',
-_("LScli : The CLI command '%{command}' already exists.")
+___("LScli : The CLI command '%{command}' already exists.")
 );
 LSerror :: defineError('LScli_02',
-_("LScli : The CLI command '%{command}' handler is not callable.")
+___("LScli : The CLI command '%{command}' handler is not callable.")
 );
 
 /*
