@@ -33,6 +33,7 @@ LSsession :: loadLSclass('LSlog_staticLoggerClass');
 class LSform extends LSlog_staticLoggerClass {
   var $ldapObject;
   var $idForm;
+  var $config;
   var $can_validate = true;
   var $elements = array();
   var $_rules = array();
@@ -72,9 +73,32 @@ class LSform extends LSlog_staticLoggerClass {
       $this -> submit = $submit;
     }
     $this -> ldapObject =& $ldapObject;
+    $this -> config = $ldapObject -> getConfig('LSform');
     LSsession :: loadLSclass('LSformElement');
   }
 
+  /**
+   * Return a configuration parameter (or default value)
+   *
+   * @param[] $param	The configuration parameter
+   * @param[] $default	The default value (default : null)
+   * @param[] $cast	Cast resulting value in specific type (default : disabled)
+   *
+   * @retval mixed The configuration parameter value or default value if not set
+   **/
+  public function getConfig($param, $default=null, $cast=null) {
+    return LSconfig :: get($param, $default, $cast, $this -> config);
+  }
+
+  /**
+   * Allow conversion of LSform to string
+   *
+   * @retval string The string representation of the LSform
+   */
+  public function __toString() {
+    return "<LSform ".$this -> idForm." on ".$this -> ldapObject -> toString(false).">";
+  }
+
   /**
    * Display the form
    *
@@ -112,7 +136,7 @@ class LSform extends LSlog_staticLoggerClass {
     );
     LStemplate :: assign('LSform_object',$LSform_object);
 
-    $layout_config=LSconfig :: get("LSobjects.".$LSform_object['type'].".LSform.layout");
+    $layout_config = $this -> getConfig("layout");
 
     if (!isset($this -> dataEntryFormConfig['disabledLayout']) || $this -> dataEntryFormConfig['disabledLayout']==false) {
       if (is_array($layout_config)) {
@@ -167,7 +191,7 @@ class LSform extends LSlog_staticLoggerClass {
     LStemplate :: assign('LSform_fields',$fields);
 
     $JSconfig = array (
-      'ajaxSubmit' => ((isset($this -> config['LSform']['ajaxSubmit']))?$this -> config['LSform']['ajaxSubmit']:1)
+      'ajaxSubmit' => intval($this -> getConfig('ajaxSubmit', true, 'boolean')),
     );
 
     if (!empty($this -> warnings)) {
@@ -246,7 +270,7 @@ class LSform extends LSlog_staticLoggerClass {
     }
     LStemplate :: assign('LSform_fields',$fields);
 
-    $layout_config=LSconfig :: get("LSobjects.".$LSform_object['type'].".LSform.layout");
+    $layout_config = $this -> getConfig("layout");
     if (is_array($layout_config)) {
       LStemplate :: assign('LSform_layout',$layout_config);
     }
@@ -367,7 +391,7 @@ class LSform extends LSlog_staticLoggerClass {
         foreach($this -> _rules[$element] as $rule) {
           $ruleType="LSformRule_".$rule['name'];
           LSsession :: loadLSclass($ruleType);
-          if (! call_user_func_array(array( $ruleType,'validate') , array($value, $rule['options'], $this -> getElement($element)))) {
+          if (! call_user_func_array(array( $ruleType,'validate') , array($value, $rule['options'], &$this -> elements[$element]))) {
             $retval=false;
             $this -> setElementError($this -> elements[$element],$rule['options']['msg']);
           }
@@ -388,7 +412,7 @@ class LSform extends LSlog_staticLoggerClass {
    */
   public function checkRequired($data) {
     foreach($data as $val) {
-      if (!empty($val)||(is_string($val)&&($val=="0")))
+      if (!is_empty($val))
         return true;
     }
     return;
@@ -658,16 +682,17 @@ class LSform extends LSlog_staticLoggerClass {
   }
 
   /**
-   * Retourne le code HTML d'un champ vide.
+   * Return the HTML code of an empty form field
    *
-   * @param[in] string Le nom du champ du formulaire
+   * @param[in] $element string The form element name
+   * @param[in] $value_idx integer|null The value index (optional, default: null == 0)
    *
-   * @retval string Le code HTML du champ vide.
+   * @retval string|null The HTML code of the specified field if exist, null otherwise
    */
-  public function getEmptyField($element) {
+  public function getEmptyField($element, $value_idx=null) {
     $element = $this -> getElement($element);
     if ($element) {
-      return $element -> getEmptyField();
+      return $element -> getEmptyField($value_idx);
     }
     else {
       return;
@@ -695,7 +720,7 @@ class LSform extends LSlog_staticLoggerClass {
    public function applyDataEntryForm($dataEntryForm) {
      $dataEntryForm=(string)$dataEntryForm;
      $objType = $this -> ldapObject -> getType();
-     $config=LSconfig :: get("LSobjects.".$objType.".LSform.dataEntryForm.".$dataEntryForm);
+     $config = $this -> getConfig("dataEntryForm.$dataEntryForm");
      if (is_array($config)) {
        if (!is_array($config['displayedElements'])) {
          LSerror :: addErrorCode('LSform_08',$dataEntryForm);
@@ -729,6 +754,7 @@ class LSform extends LSlog_staticLoggerClass {
     public static function listAvailableDataEntryForm($type) {
       $retval=array();
       if (LSsession ::loadLSobject($type)) {
+        // Static method: couldn't use $this -> getConfig()
         $config=LSconfig :: get("LSobjects.".$type.".LSform.dataEntryForm");
         if (is_array($config)) {
           foreach($config as $name => $conf) {
@@ -768,10 +794,12 @@ class LSform extends LSlog_staticLoggerClass {
         $object = new $_REQUEST['objecttype']();
         $object -> loadData($_REQUEST['objectdn']);
         $form = $object -> getForm($_REQUEST['idform']);
-        $emptyField=$form -> getEmptyField($_REQUEST['attribute']);
+        $value_idx = (isset($_REQUEST['value_idx'])?$_REQUEST['value_idx']:0);
+        $emptyField = $form -> getEmptyField($_REQUEST['attribute'], $value_idx);
         if ( $emptyField ) {
           $data = array(
-            'html' => $form -> getEmptyField($_REQUEST['attribute']),
+            'html' => $emptyField,
+            'value_idx' => $value_idx,
             'fieldId' => $_REQUEST['fieldId'],
             'fieldtype' => get_class($form -> getElement($_REQUEST['attribute']))
           );
@@ -824,30 +852,30 @@ class LSform extends LSlog_staticLoggerClass {
  * Error Codes
  */
 LSerror :: defineError('LSform_01',
-_("LSform : Error during the recovery of the values of the form.")
+___("LSform : Error during the recovery of the values of the form.")
 );
 LSerror :: defineError('LSform_02',
-_("LSform : Error durring the recovery of the value of the field '%{element}'.")
+___("LSform : Error durring the recovery of the value of the field '%{element}'.")
 );
 // No longer used
 /*LSerror :: defineError(203,
-_("LSform : Data of the field %{element} are not validate.")
+___("LSform : Data of the field %{element} are not validate.")
 );*/
 LSerror :: defineError('LSform_04',
-_("LSform : The field %{element} doesn't exist.")
+___("LSform : The field %{element} doesn't exist.")
 );
 LSerror :: defineError('LSform_05',
-_("LSfom : Field type unknow (%{type}).")
+___("LSfom : Field type unknow (%{type}).")
 );
 LSerror :: defineError('LSform_06',
-_("LSform : Error during the creation of the element '%{element}'.")
+___("LSform : Error during the creation of the element '%{element}'.")
 );
 LSerror :: defineError('LSform_07',
-_("LSform : The data entry form %{name} doesn't exist.")
+___("LSform : The data entry form %{name} doesn't exist.")
 );
 LSerror :: defineError('LSform_08',
-_("LSform : The data entry form %{name} is not correctly configured.")
+___("LSform : The data entry form %{name} is not correctly configured.")
 );
 LSerror :: defineError('LSform_09',
-_("LSform : The element %{name}, listed as displayed in data entry form configuration, doesn't exist.")
+___("LSform : The element %{name}, listed as displayed in data entry form configuration, doesn't exist.")
 );
