@@ -221,7 +221,7 @@ class LSlang extends LSlog_staticLoggerClass {
  * Only load in CLI context
  ***********************************************
  */
-if (php_sapi_name() != "cli") return;
+if (php_sapi_name() != "cli") return true;
 
 /**
  * CLI generate_lang_file command
@@ -237,7 +237,7 @@ if (php_sapi_name() != "cli") return;
 function cli_generate_lang_file($command_args) {
   // Use global variables to share it with sub-functions
   global $LSlang_cli_logger, $available_onlys, $available_withouts, $data, $translations, $interactive,
-  $copyoriginalvalue, $format, $curdir, $additionalfileformat, $copyoriginalvalue, $lang;
+  $interactive_exit, $copyoriginalvalue, $format, $curdir, $additionalfileformat, $copyoriginalvalue, $lang;
 
   // Initialize logger (if not already initialized by another CLI command)
   if (!isset($LSlang_cli_logger))
@@ -253,6 +253,7 @@ function cli_generate_lang_file($command_args) {
   $withouts = array();
   $copyoriginalvalue = False;
   $interactive = False;
+  $interactive_exit = False; // Exit flag set when user type 'q'
   $output = False;
   $additionalfileformat = False;
   $lang = null;
@@ -364,9 +365,67 @@ function cli_generate_lang_file($command_args) {
     }
   }
 
+  function interactive_ask($context, $msg) {
+    global $copyoriginalvalue, $interactive_exit;
+
+    if ($interactive_exit) {
+      if ($copyoriginalvalue)
+        return $msg;
+      return true;
+    }
+
+    // Format question
+    $empty_action = ($copyoriginalvalue?'copy original message':'pass');
+    $question ="\"$msg\"\n\n => Please enter translated string";
+    $question .= " (i";
+    if (!$copyoriginalvalue)
+      $question .= "/c";
+    $question .= "/q/? or leave empty to $empty_action): ";
+
+    while (true) {
+      if ($context)
+        fwrite(STDERR, "\n# $context\n");
+      fwrite(STDERR, $question);
+      $in = trim(fgets(STDIN));
+      switch($in) {
+        case 'q': // Exit interactive mode
+        case 'Q':
+          $interactive_exit = true;
+          return True;
+        case 'i': // Ignore
+        case 'I':
+          return True;
+        case 'c':
+        case 'C': // Copy
+          if (!$copyoriginalvalue)
+            return $msg;
+        case '?': // Help message
+          fwrite(STDERR, "Available choices:\n");
+          fwrite(STDERR, " - i: ignore this message\n");
+          if (!$copyoriginalvalue)
+            fwrite(STDERR, " - c: copy original message\n");
+          fwrite(STDERR, " - q: quit interactive mode and ignore all following untranslated messages\n");
+          fwrite(STDERR, " - ?: Show this message\n");
+          fwrite(STDERR, "Or leave empty to $empty_action.\n");
+          break;
+        case "": // Empty
+          // On copy orignal value mode, return $msg
+          if ($copyoriginalvalue)
+            return $msg;
+          // Otherwise, leave translation empty
+          return "";
+        default:
+          // Return user input
+          return $in;
+      }
+    }
+    // Supposed to never happen
+    return true;
+  }
+
   function add($msg, $context=null) {
-    global $LSlang_cli_logger, $lang, $data, $translations, $interactive, $copyoriginalvalue, $format;
-    $LSlang_cli_logger -> debug("add($msg, $context)");
+    global $LSlang_cli_logger, $lang, $data, $translations, $interactive, $interactive_exit, $copyoriginalvalue, $format;
+    $LSlang_cli_logger -> trace("add($msg, $context)");
     if ($msg == '')
       return;
     if (!is_null($lang) && _($msg) != "$msg")
@@ -388,28 +447,9 @@ function cli_generate_lang_file($command_args) {
       $translation = _($msg);
     }
     elseif ($interactive && $format != 'pot') {
-      if ($context)
-        fwrite(STDERR, "\n# $context\n");
-      if ($copyoriginalvalue) {
-        fwrite(STDERR, "\"$msg\"\n\n => Please enter translated string (or leave empty to copy original string) : ");
-        $in = trim(fgets(STDIN));
-        if ($in)
-          $translation = $in;
-        else
-          $translation = $msg;
-      }
-      else {
-        fwrite(STDERR, "\"$msg\"\n\n => Please enter translated string (or 'c' to copy original message, 'i' to ignore this message, leave empty to pass) : ");
-        $in = trim(fgets(STDIN));
-        if ($in) {
-          if ($in=="i")
-            return True;
-          if ($in=="c")
-            $translation = $msg;
-          else
-            $translation = $in;
-        }
-      }
+      $translation = interactive_ask($context, $msg);
+      if (!is_string($translation))
+        return true;
     }
     $data[$msg] = array (
       'translation' => $translation,
@@ -419,11 +459,11 @@ function cli_generate_lang_file($command_args) {
 
   function addFromLSconfig($pattern, $value='value', $excludes=array()) {
     global $LSlang_cli_logger;
-    $LSlang_cli_logger -> debug("addFromLSconfig($pattern, array(".implode(',', $excludes)."))");
+    $LSlang_cli_logger -> trace("addFromLSconfig($pattern, array(".implode(',', $excludes)."))");
     $keys = LSconfig :: getMatchingKeys($pattern);
-    $LSlang_cli_logger -> debug("addFromLSconfig : ".count($keys)." matching key(s)");
+    $LSlang_cli_logger -> trace("addFromLSconfig : ".count($keys)." matching key(s)");
     foreach ($keys as $key => $value) {
-      $LSlang_cli_logger -> debug("addFromLSconfig : $key = $value");
+      $LSlang_cli_logger -> trace("addFromLSconfig : $key = ".varDump($value));
       if ($value == 'key') {
         // Get the last key parts as value and all other as key
         $key_parts = explode('.', $key);
@@ -454,13 +494,60 @@ function cli_generate_lang_file($command_args) {
     }
   }
 
+  function addPossibleValuesFromLSconfig($context, $withouts, $level=0) {
+    global $LSlang_cli_logger;
+    $LSlang_cli_logger -> trace("addPossibleValuesFromLSconfig($context)");
+    if (in_array('select-list', $withouts))
+      return true;
+    if (!LSconfig :: get("$context.translate_labels", True, "bool"))
+      return true;
+    foreach(LSconfig :: get("$context.possible_values", array()) as $pkey => $plabel) {
+      if (is_array($plabel)) {
+        // Sub possible values
+        // Check level
+        if ($level > 1) {
+          $LSlang_cli_logger -> warning(
+            "addPossibleValuesFromLSconfig($context): Level to hight to handle sub possible values of $context.possible_values.$pkey"
+          );
+          return true;
+        }
+        addFromLSconfig("$context.possible_values.$pkey.label");
+        $LSlang_cli_logger -> trace("addPossibleValuesFromLSconfig($context): handle sub possible values of $context.possible_values.$pkey");
+        addPossibleValuesFromLSconfig("$context.possible_values.$pkey", $withouts, $level+1);
+      }
+      else {
+        switch ($pkey) {
+          case 'OTHER_OBJECT':
+            $LSlang_cli_logger -> trace("addPossibleValuesFromLSconfig($context): ignore $context.possible_values.$pkey (OTHER_OBJECT)");
+            break;
+          case 'OTHER_ATTRIBUTE':
+            if (is_array($plabel)) {
+              if (isset($plabel['json_component_key']))
+                addFromLSconfig("$context.possible_values.OTHER_ATTRIBUTE.json_component_label");
+              else
+                addFromLSconfig("$context.possible_values.OTHER_ATTRIBUTE.*");
+            }
+            else {
+              $LSlang_cli_logger -> warning("addPossibleValuesFromLSconfig($context): invalid $context.possible_values.OTHER_ATTRIBUTE config => Must be an array.");
+            }
+            break;
+          default:
+            add($plabel, "$context.possible_values.$pkey");
+            break;
+        }
+      }
+    }
+  }
+
   /*
    * Manage configuration parameters
    */
   if (!in_array('config', $withouts) && (!$only || $only == 'config')) {
     // LDAP Servers
     $objects = array();
+    $LSlang_cli_logger -> info("Looking for string to translate configuration of LDAP servers");
     foreach(LSconfig :: keys('ldap_servers') as $ldap_server_id) {
+      $LSlang_cli_logger -> debug("Looking for string to translate configuration of LDAP server #$ldap_server_id");
       addFromLSconfig("ldap_servers.$ldap_server_id.name");
       addFromLSconfig("ldap_servers.$ldap_server_id.subDnLabel");
       addFromLSconfig("ldap_servers.$ldap_server_id.recoverPassword.recoveryHashMail.subject");
@@ -488,6 +575,7 @@ function cli_generate_lang_file($command_args) {
 
     // LSobject
     foreach($objects as $obj) {
+      $LSlang_cli_logger -> info("Looking for string to translate configuration of object type $obj");
       addFromLSconfig("LSobjects.$obj.label");
 
       // LSrelation
@@ -533,52 +621,8 @@ function cli_generate_lang_file($command_args) {
               addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.help_info");
               addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.check_data.*.msg");
 
-              if (
-                    LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.components.$c.type") == 'select_list' &&
-                    LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.translate_labels", "True", "bool") &&
-                    !in_array('select-list', $withouts)
-                 )
-              {
-                foreach(LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values", array()) as $pkey => $plabel) {
-                  if (is_string($pkey)) {
-                    if ($pkey == 'OTHER_OBJECT')
-                      continue;
-                    elseif ($pkey == 'OTHER_ATTRIBUTE') {
-                      if (is_string($plabel))
-                        continue;
-                      elseif (is_array($plabel)) {
-                        if (isset($plabel['json_component_key']))
-                          addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.OTHER_ATTRIBUTE.json_component_label");
-                        else
-                          addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.OTHER_ATTRIBUTE.*");
-                      }
-                    }
-                    else
-                      add($plabel, "LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.$pkey");
-                  }
-                  elseif (is_int($pkey) && is_array($plabel)) {
-                    // Sub possible values
-                    addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.$pkey.label");
-                    foreach(LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.$pkey.possible_values", array()) as $ppkey => $pplabel) {
-                      if ($ppkey == 'OTHER_OBJECT')
-                        continue;
-                      elseif ($ppkey == 'OTHER_ATTRIBUTE') {
-                        if (is_string($pplabel))
-                          continue;
-                        elseif (is_array($pplabel)) {
-                          if (isset($pplabel['json_component_key']))
-                            addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.OTHER_ATTRIBUTE.json_component_label");
-                          else
-                            addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.OTHER_ATTRIBUTE.*");
-                        }
-                      }
-                      elseif(is_string($pplabel)) {
-                        add($pplabel, "LSobjects.$obj.attrs.$attr.html_options.components.$c.options.possible_values.$pkey.possible_values.$ppkey");
-                      }
-                    }
-                  }
-                }
-              }
+              if (LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.components.$c.type") == 'select_list')
+                addPossibleValuesFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.components.$c.options", $withouts);
             }
             break;
           case 'labeledValue':
@@ -591,51 +635,14 @@ function cli_generate_lang_file($command_args) {
             break;
           case 'select_list':
           case 'select_box':
-            if (LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.translate_labels", "True", "bool") && !in_array('select-list', $withouts)) {
-              foreach(LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.possible_values", array()) as $pkey => $plabel) {
-                if (is_string($pkey)) {
-                  if ($pkey == 'OTHER_OBJECT')
-                    continue;
-                  elseif ($pkey == 'OTHER_ATTRIBUTE') {
-                    if (is_string($plabel))
-                      continue;
-                    elseif (is_array($plabel)) {
-                      if (isset($plabel['json_component_key']))
-                        addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.possible_values.OTHER_ATTRIBUTE.json_component_label");
-                      else
-                        addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.possible_values.OTHER_ATTRIBUTE.*");
-                    }
-                  }
-                  else
-                    add($plabel, "LSobjects.$obj.attrs.$attr.html_options.possible_values.$pkey");
-                }
-                elseif (is_int($pkey) && is_array($plabel)) {
-                  // Sub possible values
-                  addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.possible_values.$pkey.label");
-                  foreach(LSconfig :: get("LSobjects.$obj.attrs.$attr.html_options.possible_values.$pkey.possible_values", array()) as $ppkey => $pplabel) {
-                    if ($ppkey == 'OTHER_OBJECT')
-                      continue;
-                    elseif ($ppkey == 'OTHER_ATTRIBUTE') {
-                      if (is_string($pplabel))
-                        continue;
-                      elseif (is_array($pplabel)) {
-                        if (isset($pplabel['json_component_key']))
-                          addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.possible_values.OTHER_ATTRIBUTE.json_component_label");
-                        else
-                          addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.possible_values.OTHER_ATTRIBUTE.*");
-                      }
-                    }
-                    elseif(is_string($pplabel)) {
-                      add($pplabel, "LSobjects.$obj.attrs.$attr.html_options.possible_values.$pkey.possible_values.$ppkey");
-                    }
-                  }
-                }
-              }
-            }
+            addPossibleValuesFromLSconfig("LSobjects.$obj.attrs.$attr.html_options", $withouts);
             break;
           case 'valueWithUnit':
             addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.units.*");
             break;
+          case 'date':
+            addFromLSconfig("LSobjects.$obj.attrs.$attr.html_options.special_values.*");
+            break;
         }
       }
     }
@@ -647,19 +654,19 @@ function cli_generate_lang_file($command_args) {
   if (!in_array('templates', $withouts) && (!$only || $only == 'templates')) {
     function parse_template_file($file) {
       global $LSlang_cli_logger;
-      $LSlang_cli_logger -> debug("parse_template_file($file) : start ...");
+      $LSlang_cli_logger -> debug("Looking for string to translate in '$file' template file");
       $count = 0;
       foreach(file($file) as $line) {
         $count ++;
         if (preg_match_all('/\{ *tr +msg=["\']([^\}]+)["\'] *\}/',$line,$matches)) {
           foreach($matches[1] as $t) {
             $t = preg_replace('/[\'"]\|escape\:.*$/', '', $t);
-            $LSlang_cli_logger -> debug("  - \"$t\" # Line $count");
+            $LSlang_cli_logger -> trace("  - \"$t\" # Line $count");
             add($t, absolute2relative_path($file).":$count");
           }
         }
       }
-      $LSlang_cli_logger -> debug("parse_template_file($file) : done.");
+      $LSlang_cli_logger -> trace("parse_template_file($file) : done.");
     }
 
     function find_and_parse_template_file($dir) {
@@ -678,6 +685,7 @@ function cli_generate_lang_file($command_args) {
         }
       }
     }
+    $LSlang_cli_logger -> info("Looking for string to translate in templates file");
     find_and_parse_template_file(LS_ROOT_DIR.'/'.LS_TEMPLATES_DIR);
     find_and_parse_template_file(LS_ROOT_DIR.'/'.LS_LOCAL_DIR.LS_TEMPLATES_DIR);
   }
@@ -689,7 +697,7 @@ function cli_generate_lang_file($command_args) {
   if (!in_array('addons', $withouts) && (!$only || $only == 'addons')) {
     function parse_addon_file($file) {
       global $LSlang_cli_logger;
-      $LSlang_cli_logger -> debug("parse_addon_file($file)");
+      $LSlang_cli_logger -> debug("Looking for string to translate in '$file' LSaddon file");
       $count = 0;
       foreach(file($file) as $line) {
         $count++;
@@ -755,6 +763,7 @@ function cli_generate_lang_file($command_args) {
       }
     }
 
+    $LSlang_cli_logger -> info("Looking for string to translate in LSaddons PHP code");
     find_and_parse_addon_file(LS_ROOT_DIR.'/'.LS_ADDONS_DIR);
     find_and_parse_addon_file(LS_ROOT_DIR.'/'.LS_LOCAL_DIR.LS_ADDONS_DIR);
   }
@@ -816,6 +825,7 @@ function cli_generate_lang_file($command_args) {
   // Determine where to write result
   if ($output) {
     $output = relative2absolute_path($output);
+    $LSlang_cli_logger -> info("Write result in output file ($output)");
     try {
       $LSlang_cli_logger -> debug("Open output file ($output)");
       $fd = fopen($output, 'w');
