@@ -42,6 +42,8 @@ class LSlog_console extends LSlog_handler {
 		parent :: __construct($config);
 		$this -> stdout = fopen('php://stdout', 'w');
 		$this -> stderr = fopen('php://stderr', 'w');
+		if ($this -> enabled)
+			self :: log_trace("$this Enabled", get_class($this));
 	}
 
 	/**
