@@ -20,12 +20,14 @@
 
 ******************************************************************************/
 
+LSsession :: loadLSclass('LSlog_staticLoggerClass');
+
 /**
  * Logger class for LSlog
  *
  * @author Benjamin Renard <brenard@easter-eggs.com>
  */
-class LSlog_logger {
+class LSlog_logger extends LSlog_staticLoggerClass {
 
 	// Name
 	private $name;
@@ -52,10 +54,17 @@ class LSlog_logger {
 		$this -> config = $config;
 		$this -> enabled = $this -> getConfig('enabled', true, 'boolean');
 		$this -> level = $this -> getConfig('level');
-		if ($this -> enabled)
-			$this -> debug("Enabled $name logger with level=".$this -> level);
 	}
 
+  /**
+   * Allow conversion of LSlog_logger to string
+   *
+   * @retval string The string representation of the LSlog_logger
+   */
+  public function __toString() {
+    return "<".get_class($this)." ".$this -> name.">";
+  }
+
 	/**
 	 * Get a configuration variable value
 	 *
@@ -88,6 +97,8 @@ class LSlog_logger {
 			case 'level':
 				return $this -> level;
 		}
+		// Unknown key, log warning
+		self :: log_warning("$this -> __get($key): invalid property requested\n".LSlog :: get_debug_backtrace_context());
 		return;
 	}
 
