@@ -52,7 +52,7 @@ class LSrelation extends LSlog_staticLoggerClass {
     if (!is_array($this -> config) || !$this -> checkConfig()) {
       $this -> config = null;
       LSerror :: addErrorCode(
-        'LSrelations_02',
+        'LSrelation_02',
         array(
           'relation' => $relationName,
           'LSobject' => $obj -> getType()
@@ -61,6 +61,15 @@ class LSrelation extends LSlog_staticLoggerClass {
     }
   }
 
+  /**
+   * Allow conversion of LSrelation to string
+   *
+   * @retval string The string representation of the LSrelation
+   */
+  public function __toString() {
+    return "<LSrelation ".$this -> name." on ".$this -> obj -> toString(false).">";
+  }
+
   /**
    * Return a configuration parameter (or default value)
    *
@@ -71,6 +80,9 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval mixed The configuration parameter value or default value if not set
    **/
   public function getConfig($param, $default=null, $cast=null) {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
     return LSconfig :: get($param, $default, $cast, $this -> config);
   }
 
@@ -85,6 +97,8 @@ class LSrelation extends LSlog_staticLoggerClass {
     switch ($key) {
       case 'name':
         return $this -> name;
+      case 'correctly_configured':
+        return boolval($this -> config);
       case 'LSobject':
       case 'linkAttribute':
       case 'linkAttributeValue':
@@ -108,6 +122,8 @@ class LSrelation extends LSlog_staticLoggerClass {
           $this -> getConfig('linkAttribute', false)
         );
     }
+    // Unknown key, log warning
+		self :: log_warning("__get($key): invalid property requested\n".LSlog :: get_debug_backtrace_context());
   }
 
   /**
@@ -119,7 +135,7 @@ class LSrelation extends LSlog_staticLoggerClass {
     // Check LSobject parameter
     if (!$this -> LSobject) {
       LSerror :: addErrorCode(
-        'LSrelations_07',
+        'LSrelation_07',
         array(
           'parameter' => 'LSobject',
           'relation' => $this -> name,
@@ -132,7 +148,7 @@ class LSrelation extends LSlog_staticLoggerClass {
     // Load related object type
     if (!LSsession :: loadLSobject($this -> LSobject)) {
       LSerror :: addErrorCode(
-        'LSrelations_04',
+        'LSrelation_04',
         array(
           'relation' => $this -> name,
           'LSobject' => $this -> LSobject
@@ -146,7 +162,7 @@ class LSrelation extends LSlog_staticLoggerClass {
       // Check linkAttribute refered to an existing related object type attribute
       if (!call_user_func(array($this -> LSobject, 'hasAttr'), $this -> linkAttribute)) {
         LSerror :: addErrorCode(
-          'LSrelations_08',
+          'LSrelation_08',
           array(
             'parameter' => 'linkAttribute',
             'relation' => $this -> name,
@@ -159,7 +175,7 @@ class LSrelation extends LSlog_staticLoggerClass {
       // Check linkAttributeValue
       if ($this -> linkAttributeValue != 'dn' && !$this -> obj -> hasAttr($this -> linkAttributeValue)) {
         LSerror :: addErrorCode(
-          'LSrelations_08',
+          'LSrelation_08',
           array(
             'parameter' => 'linkAttributeValue',
             'relation' => $this -> name,
@@ -182,7 +198,7 @@ class LSrelation extends LSlog_staticLoggerClass {
       // Check parameter is defined
       if (!$this -> $p) {
         LSerror :: addErrorCode(
-          'LSrelations_07',
+          'LSrelation_07',
           array(
             'parameter' => $p,
             'relation' => $this -> name,
@@ -195,7 +211,7 @@ class LSrelation extends LSlog_staticLoggerClass {
       // Check parameter refered to an existing related object class method
       if (!method_exists($this -> LSobject, $this -> $p)) {
         LSerror :: addErrorCode(
-          'LSrelations_01',
+          'LSrelation_01',
           array(
             'parameter' => $p,
             'function' => $this -> $p,
@@ -257,10 +273,14 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval array|false An array of related objects (LSldapObject), of false in case of error
    */
   public function listRelatedObjects() {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
+
     // Load related object type
     if (!LSsession :: loadLSobject($this -> LSobject)) {
       LSerror :: addErrorCode(
-        'LSrelations_04',
+        'LSrelation_04',
         array(
           'relation' => $this -> name,
           'LSobject' => $this -> LSobject
@@ -281,7 +301,7 @@ class LSrelation extends LSlog_staticLoggerClass {
         );
       }
       LSerror :: addErrorCode(
-        'LSrelations_01',
+        'LSrelation_01',
         array(
           'parameter' => 'list_function',
           'function' => $this -> list_function,
@@ -304,7 +324,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Configuration problem
     LSerror :: addErrorCode(
-      'LSrelations_05',
+      'LSrelation_05',
       array(
         'relation' => $this -> name,
         'LSobject' => $this -> LSobject,
@@ -320,10 +340,14 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval array List of value of the link attribute
    */
   public function getRelatedKeyValue() {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
+
     // Load related object type
     if (!LSsession :: loadLSobject($this -> LSobject)) {
       LSerror :: addErrorCode(
-        'LSrelations_04',
+        'LSrelation_04',
         array(
           'relation' => $this -> name,
           'LSobject' => $this -> LSobject
@@ -344,7 +368,7 @@ class LSrelation extends LSlog_staticLoggerClass {
         );
       }
       LSerror :: addErrorCode(
-        'LSrelations_01',
+        'LSrelation_01',
         array(
           'parameter' => 'getkeyvalue_function',
           'function' => $this -> getkeyvalue_function,
@@ -366,7 +390,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Configuration problem
     LSerror :: addErrorCode(
-      'LSrelations_05',
+      'LSrelation_05',
       array(
         'relation' => $this -> name,
         'LSobject' => $this -> LSobject,
@@ -384,6 +408,10 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval boolean True if user can edit the relation with the specified object, false otherwise
    */
   public function canEditRelationWithObject(&$objRel) {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
+
     if (!$this -> canEdit()) return;
 
     // Use canEdit_function
@@ -392,7 +420,7 @@ class LSrelation extends LSlog_staticLoggerClass {
         return call_user_func(array($objRel, $this -> canEdit_function));
       }
       LSerror :: addErrorCode(
-        'LSrelations_01',
+        'LSrelation_01',
         array(
           'parameter' => 'canEdit_function',
           'function' => $this -> canEdit_function,
@@ -414,7 +442,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Configuration problem
     LSerror :: addErrorCode(
-      'LSrelations_05',
+      'LSrelation_05',
       array(
         'relation' => $this -> name,
         'LSobject' => $this -> LSobject,
@@ -432,6 +460,10 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval boolean True if relation removed, false otherwise
    */
   public function removeRelationWithObject(&$objRel) {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
+
     // Use remove_function
     if ($this -> remove_function) {
       if (method_exists($this -> LSobject, $this -> remove_function)) {
@@ -441,7 +473,7 @@ class LSrelation extends LSlog_staticLoggerClass {
         );
       }
       LSerror :: addErrorCode(
-        'LSrelations_01',
+        'LSrelation_01',
         array(
           'parameter' => 'remove_function',
           'function' => $this -> remove_function,
@@ -459,7 +491,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Configuration problem
     LSerror :: addErrorCode(
-      'LSrelations_05',
+      'LSrelation_05',
       array(
         'relation' => $this -> name,
         'LSobject' => $this -> LSobject,
@@ -478,13 +510,17 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval boolean True if relation rename, false otherwise
    */
   public function renameRelationWithObject(&$objRel, $oldKeyValue) {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
+
     // Use rename_function
     if ($this -> rename_function) {
       if (method_exists($objRel,$this -> rename_function)) {
         return call_user_func_array(array($objRel, $this -> rename_function), array(&$this -> obj, $oldKeyValue));
       }
       LSerror :: addErrorCode(
-        'LSrelations_01',
+        'LSrelation_01',
         array(
           'parameter' => 'rename_function',
           'function' => $this -> rename_function,
@@ -508,7 +544,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Configuration problem
     LSerror :: addErrorCode(
-      'LSrelations_05',
+      'LSrelation_05',
       array(
         'relation' => $this -> name,
         'LSobject' => $this -> LSobject,
@@ -526,10 +562,14 @@ class LSrelation extends LSlog_staticLoggerClass {
    * @retval boolean True if relations updated, false otherwise
    */
   public function updateRelations($listDns) {
+    // Check relation is correctly configured
+    if (!$this -> correctly_configured)
+      return false;
+
     // Load related objects type
     if (!LSsession :: loadLSobject($this -> LSobject)) {
       LSerror :: addErrorCode(
-        'LSrelations_04',
+        'LSrelation_04',
         array(
           'relation' => $this -> name,
           'LSobject' => $this -> LSobject
@@ -550,7 +590,7 @@ class LSrelation extends LSlog_staticLoggerClass {
         );
       }
       LSerror :: addErrorCode(
-        'LSrelations_01',
+        'LSrelation_01',
         array(
           'parameter' => 'update_function',
           'function' => $this -> update_function,
@@ -576,7 +616,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Configuration problem
     LSerror :: addErrorCode(
-      'LSrelations_05',
+      'LSrelation_05',
       array(
         'relation' => $this -> name,
         'LSobject' => $this -> LSobject,
@@ -622,7 +662,7 @@ class LSrelation extends LSlog_staticLoggerClass {
       return;
 
     $LSrelations=array();
-    $LSrelations_JSparams=array();
+    $LSrelation_JSparams=array();
     foreach($object -> getConfig('LSrelation') as $relationName => $relationConf) {
       // Check user access
       if (!LSsession :: relationCanAccess($object -> getValue('dn'), $object->getType(), $relationName)) {
@@ -644,7 +684,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
       $id=rand();
       $return['id']=$id;
-      $LSrelations_JSparams[$id]=array(
+      $LSrelation_JSparams[$id]=array(
         'emptyText' => $return['emptyText']
       );
       $_SESSION['LSrelation'][$id] = array(
@@ -653,6 +693,8 @@ class LSrelation extends LSlog_staticLoggerClass {
         'objectDn' => $object -> getDn(),
       );
       $relation = new LSrelation($object, $relationName);
+      if (!$relation -> correctly_configured)
+        continue;
 
       if ($relation -> canEdit()) {
         $return['actions'][] = array(
@@ -692,7 +734,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     self :: loadDependenciesDisplay();
     LStemplate :: assign('LSrelations',$LSrelations);
-    LStemplate :: addJSconfigParam('LSrelations',$LSrelations_JSparams);
+    LStemplate :: addJSconfigParam('LSrelations',$LSrelation_JSparams);
   }
 
   /*
@@ -761,6 +803,10 @@ class LSrelation extends LSlog_staticLoggerClass {
     // Instanciate relation
     $relation = new LSrelation($object, $conf['relationName']);
 
+    // Check relation is correctly configured
+    if (!$relation -> correctly_configured)
+      return false;
+
     // Check user access to it relation
     if (!$relation -> canEdit()) {
       LSerror :: addErrorCode('LSsession_11');
@@ -857,7 +903,7 @@ class LSrelation extends LSlog_staticLoggerClass {
 
     // Update related objects
     if (!$relation -> updateRelations(array_keys($selected_objects))) {
-      LSerror :: addErrorCode('LSrelations_03', $conf['relationName']);
+      LSerror :: addErrorCode('LSrelation_03', $conf['relationName']);
       self :: log_warning("Fail to update objects in relation");
       return;
     }
@@ -907,7 +953,7 @@ class LSrelation extends LSlog_staticLoggerClass {
     $list = $relation -> listRelatedObjects();
     if (!is_array($list)) {
       self :: log_warning('Fail to list related objects');
-      LSerror :: addErrorCode('LSrelations_03',$conf['relationName']);
+      LSerror :: addErrorCode('LSrelation_03',$conf['relationName']);
       return;
     }
 
@@ -923,7 +969,7 @@ class LSrelation extends LSlog_staticLoggerClass {
           return;
         }
         if (!$relation -> removeRelationWithObject($o)) {
-          LSerror :: addErrorCode('LSrelations_03', $conf['relationName']);
+          LSerror :: addErrorCode('LSrelation_03', $conf['relationName']);
           return;
         }
         else {
@@ -936,7 +982,7 @@ class LSrelation extends LSlog_staticLoggerClass {
     // Check object found
     if (!$found) {
       self :: log_warning("Object '".$_REQUEST['dn']."' not found in related objects list.");
-      LSerror :: addErrorCode('LSrelations_03', $conf['relationName']);
+      LSerror :: addErrorCode('LSrelation_03', $conf['relationName']);
       return;
     }
 
@@ -950,27 +996,27 @@ class LSrelation extends LSlog_staticLoggerClass {
 /**
  * Error Codes
  **/
-LSerror :: defineError('LSrelations_01',
-_("LSrelation : Invalid parameter '%{parameter}' of the relation %{relation}: objects %{LSobject} have no function '%{function}'.")
+LSerror :: defineError('LSrelation_01',
+___("LSrelation : Invalid parameter '%{parameter}' of the relation %{relation}: objects %{LSobject} have no function '%{function}'.")
 );
-LSerror :: defineError('LSrelations_02',
-_("LSrelation : Relation %{relation} of object type %{LSobject} unknown.")
+LSerror :: defineError('LSrelation_02',
+___("LSrelation : Relation %{relation} of object type %{LSobject} unknown.")
 );
-LSerror :: defineError('LSrelations_03',
-_("LSrelation : Error during relation update of the relation %{relation}.")
+LSerror :: defineError('LSrelation_03',
+___("LSrelation : Error during relation update of the relation %{relation}.")
 );
-LSerror :: defineError('LSrelations_04',
-_("LSrelation : Object type %{LSobject} unknown (Relation : %{relation}).")
+LSerror :: defineError('LSrelation_04',
+___("LSrelation : Object type %{LSobject} unknown (Relation : %{relation}).")
 );
-LSerror :: defineError('LSrelations_05',
-_("LSrelation : Incomplete configuration for LSrelation %{relation} of object type %{LSobject} for action : %{action}.")
+LSerror :: defineError('LSrelation_05',
+___("LSrelation : Incomplete configuration for LSrelation %{relation} of object type %{LSobject} for action : %{action}.")
 );
-LSerror :: defineError('LSrelations_06',
-_("LSrelation : Invalid editable attribute for LSrelation %{relation} with LSobject %{LSobject}.")
+LSerror :: defineError('LSrelation_06',
+___("LSrelation : Invalid editable attribute for LSrelation %{relation} with LSobject %{LSobject}.")
 );
-LSerror :: defineError('LSrelations_07',
-_("LSrelation : The configuration parameter '%{parameter}' of the relation %{relation} of %{LSobject} is missing.")
+LSerror :: defineError('LSrelation_07',
+___("LSrelation : The configuration parameter '%{parameter}' of the relation %{relation} of %{LSobject} is missing.")
 );
-LSerror :: defineError('LSrelations_08',
-_("LSrelation : The configuration parameter '%{parameter}' of the relation %{relation} of %{LSobject} is invalid.")
+LSerror :: defineError('LSrelation_08',
+___("LSrelation : The configuration parameter '%{parameter}' of the relation %{relation} of %{LSobject} is invalid.")
 );
