@@ -70,9 +70,6 @@ class LSsearch extends LSlog_staticLoggerClass {
   // The cache of search parameters
   private $_searchParams = NULL;
 
-  // The cache of the hash of the search parameters
-  private $_hash = NULL;
-
   // The result of the search
   private $result=NULL;
 
@@ -104,7 +101,6 @@ class LSsearch extends LSlog_staticLoggerClass {
 
     if (!$purgeParams) {
       if (! $this -> loadParamsFromSession()) {
-        self :: log_debug('LSsearch : load default parameters');
         $this -> loadDefaultParameters();
       }
     }
@@ -119,6 +115,16 @@ class LSsearch extends LSlog_staticLoggerClass {
 
   }
 
+  /**
+   * Allow conversion of LSsearch to string
+   *
+   * @retval string The string representation of the LSsearch
+   */
+  public function __toString() {
+    $search_params = $this -> formatSearchParams();
+    return "<LSsearch of ".$this -> LSobject." (context=".$this -> context.")".($search_params?" $search_params":"").">";
+  }
+
   /**
    * Load configuration from LSconfig
    *
@@ -143,8 +149,11 @@ class LSsearch extends LSlog_staticLoggerClass {
    */
   private function loadDefaultParameters() {
     if (isset($this -> config['params']) && is_array($this -> config['params'])) {
+      self :: log_debug('Load default parameters (from object type configuration)');
       return $this -> setParams($this -> config['params']);
     }
+    else
+      self :: log_trace('loadDefaultParameters(): no parameters found in object type configuration');
     return true;
   }
 
@@ -154,8 +163,8 @@ class LSsearch extends LSlog_staticLoggerClass {
    * @retval boolean True if params has been loaded from session or False
    */
   private function loadParamsFromSession() {
-    self :: log_debug('LSsearch : load context params session '.$this -> context);
     if (isset($_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context]) && is_array($_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context])) {
+      self :: log_debug('Load params from session for context '.$this -> context);
       $params = $_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context];
 
       if ($params['filter']) {
@@ -165,6 +174,8 @@ class LSsearch extends LSlog_staticLoggerClass {
       $this -> params = $params;
       return true;
     }
+    else
+      self :: log_trace("loadParamsFromSession(): no params in session for context ".$this -> context);
     return;
   }
 
@@ -174,7 +185,7 @@ class LSsearch extends LSlog_staticLoggerClass {
    * @retval void
    */
   private function saveParamsInSession() {
-    self :: log_debug('LSsearch : save context params session '.$this -> context);
+    self :: log_debug('Save context params session '.$this -> context);
     $params = $this -> params;
     if ($params['filter'] instanceof Net_LDAP2_Filter) {
       $params['filter'] = $params['filter'] -> asString();
@@ -182,7 +193,7 @@ class LSsearch extends LSlog_staticLoggerClass {
 
     foreach ($params as $param => $value) {
       if ( !isset($_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context][$param]) || $_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context][$param]!=$value) {
-        self :: log_debug("S: $param => ".varDump($value));
+        self :: log_trace("$param => ".varDump($value));
         $_SESSION['LSsession']['LSsearch'][$this -> LSobject]['params'][$this -> context][$param]=$value;
       }
     }
@@ -740,9 +751,6 @@ class LSsearch extends LSlog_staticLoggerClass {
    * @retval void
    **/
   private function generateSearchParams() {
-    // Purge the cache of the hash
-    $this -> _hash = NULL;
-
     // Base
     $retval = array(
       'filter' => $this -> params['filter'],
@@ -833,13 +841,15 @@ class LSsearch extends LSlog_staticLoggerClass {
         $attrs=array();
         if (isset($conf['LSformat'])) {
           $attrs=getFieldInFormat($conf['LSformat']);
-          if(is_array($conf['alternativeLSformats'])) {
-            foreach ($conf['alternativeLSformats'] as $format) {
-              $attrs=array_merge($attrs,getFieldInFormat($format));
+          if (isset($conf['alternativeLSformats'])) {
+            if(is_array($conf['alternativeLSformats'])) {
+              foreach ($conf['alternativeLSformats'] as $format) {
+                $attrs = array_merge($attrs, getFieldInFormat($format));
+              }
+            }
+            else {
+              $attrs = array_merge($attrs, getFieldInFormat($conf['alternativeLSformats']));
             }
-          }
-          else {
-            $attrs=array_merge($attrs,getFieldInFormat($conf['alternativeLSformats']));
           }
           if(isset($conf['formaterLSformat'])) {
             $attrs=array_unique(array_merge($attrs,getFieldInFormat($conf['formaterLSformat'])));
@@ -867,6 +877,31 @@ class LSsearch extends LSlog_staticLoggerClass {
     $this -> _searchParams = $retval;
   }
 
+  /**
+   * Format search parameters for logging
+   *
+   * @retval string|null Formated search parameters is defined, or null if not
+   **/
+  private function formatSearchParams() {
+    if (!$this -> _searchParams)
+      return;
+    if ($this -> _searchParams['filter'] instanceof Net_LDAP2_Filter)
+      $return = "filter=".$this -> _searchParams['filter']->asString();
+    else
+      $return = "without filter";
+    $return .= ", on basedn '".$this -> _searchParams['basedn']."'";
+    $return .= " (scope: ".($this -> _searchParams['scope']?$this -> _searchParams['scope']:'default');
+    if ($this -> _searchParams['attronly'])
+      $return .= ", attrs only)";
+    else
+      $return .= ", attrs: ".(
+        (is_array($this -> _searchParams['attributes']) && $this -> _searchParams['attributes'])?
+        implode(',', $this -> _searchParams['attributes']):
+        'all'
+      ).")";
+    return $return;
+  }
+
   /**
    * Get search attributes
    *
@@ -887,22 +922,22 @@ class LSsearch extends LSlog_staticLoggerClass {
    */
   public function run($cache=true) {
     $this -> generateSearchParams();
-    if ($this -> _searchParams['filter'] instanceof Net_LDAP2_Filter) {
-      self :: log_debug('LSsearch : filter : '.$this -> _searchParams['filter']->asString());
-    }
-    self :: log_debug('LSsearch : basedn : '.$this -> _searchParams['basedn'].' - scope : '.$this -> _searchParams['scope']);
+    self :: log_debug($this." -> run(".($cache?'with cache':'without cache').")");
 
     if( $cache && (!isset($_REQUEST['refresh'])) && (!$this -> params['withoutCache']) ) {
-      self :: log_debug('LSsearch : with the cache');
+      self :: log_debug($this.' -> run(): Cache enabled');
       $this -> result = $this -> getResultFromCache();
+      if ($this -> result)
+        self :: log_debug($this.' -> run(): result retreived from cache');
+      else
+        self :: log_debug($this.' -> run(): result not found in cache');
     }
     else {
-      self :: log_debug('LSsearch : without the cache');
-      $this -> setParam('withoutCache',false);
+      self :: log_debug($this.' -> run(): Cache disabled');
+      $this -> setParam('withoutCache', false);
     }
 
     if (!$this -> result) {
-      self :: log_debug('LSsearch : Not in cache');
       $this -> result=array(
         'sortBy' => NULL,
         'sortDirection' => NULL
@@ -921,23 +956,25 @@ class LSsearch extends LSlog_staticLoggerClass {
         return;
       }
 
+      // Handle onlyAccessible parameter
       if ($this -> getParam('onlyAccessible') && LSsession :: getLSuserObjectDn()) {
-        $this -> result['list']=array();
+        self :: log_debug($this.' -> run(): Filter on only accessible object');
+        $this -> result['list'] = array();
 
         // Check user rights on objets
         foreach($list as $id => $obj) {
-          if (LSsession :: canAccess($this -> LSobject,$obj['dn'])) {
-            $this -> result['list'][]=$obj;
+          if (LSsession :: canAccess($this -> LSobject, $obj['dn'])) {
+            $this -> result['list'][] = $obj;
           }
         }
       }
-      else {
-	$this -> result['list']=$list;
-      }
-
+      else
+        $this -> result['list'] = $list;
       $this -> addResultToCache();
     }
 
+    self :: log_debug($this.' -> run(): '.$this -> total. " object(s) found");
+
     $this -> doSort();
 
     return true;
@@ -947,20 +984,25 @@ class LSsearch extends LSlog_staticLoggerClass {
    * Return an hash corresponding to the parameters of the search
    *
    * @param[in] $searchParams array An optional search params array
+   * @param[in] $onlyAccessible boolean An optional onlyAccessible boolean flag
    *
    * @retval string The hash of the parameters of the search
    **/
-  public function getHash($searchParams=null) {
-    if(is_null($searchParams)) {
-      $searchParams=$this -> _searchParams;
-      if ($this -> _hash) {
-        return $this -> _hash;
-      }
+  public function getHash($searchParams=null, $onlyAccessible=null) {
+    if (is_null($searchParams)) {
+      $searchParams = $this -> _searchParams;
     }
+    if (!$searchParams)
+      return false;
     if ($searchParams['filter'] instanceof Net_LDAP_Filter) {
-      $searchParams['filter']=$searchParams['filter']->asString();
+      $searchParams['filter'] = $searchParams['filter'] -> asString();
     }
-    return hash('md5',print_r($searchParams,true));
+    $to_hash = print_r($searchParams, true);
+    if (is_null($onlyAccessible)) {
+      $onlyAccessible = ($this -> getParam('onlyAccessible') && LSsession :: getLSuserObjectDn());
+    }
+    $to_hash .= '-onlyAccessible='.intval($onlyAccessible);
+    return hash('md5', print_r($searchParams, true));
   }
 
   /**
@@ -970,10 +1012,12 @@ class LSsearch extends LSlog_staticLoggerClass {
    **/
   public function addResultToCache() {
     if ($this -> cacheIsEnabled()) {
-      self :: log_debug('LSsearch : Save result in cache.');
-      $hash=$this->getHash();
+      $hash = $this->getHash();
+      self :: log_trace("addResultToCache(): Save result in cache with hash '$hash'.");
       $_SESSION['LSsession']['LSsearch'][$this -> LSobject][$hash]=$this->result;
     }
+    else
+      self :: log_trace('addResultToCache(): cache is disabled.');
   }
 
   /**
@@ -985,10 +1029,13 @@ class LSsearch extends LSlog_staticLoggerClass {
     if ($this -> cacheIsEnabled()) {
       $hash=$this->getHash();
       if (isset($_SESSION['LSsession']['LSsearch'][$this -> LSobject][$hash])) {
-        self :: log_debug('LSsearch : Load result from cache.');
+        self :: log_trace('getResultFromCache(): result found in cache.');
         return $_SESSION['LSsession']['LSsearch'][$this -> LSobject][$hash];
       }
+      self :: log_trace('getResultFromCache(): result not found in cache.');
     }
+    else
+      self :: log_trace('getResultFromCache(): cache is disabled.');
     return;
   }
 
@@ -1014,8 +1061,6 @@ class LSsearch extends LSlog_staticLoggerClass {
     );
 
     if ($retval['total']>0) {
-      self :: log_debug('Total : '.$retval['total']);
-
       if (!$this->params['nbObjectsByPage']) {
         $this->params['nbObjectsByPage']=NB_LSOBJECT_LIST;
       }
@@ -1030,7 +1075,13 @@ class LSsearch extends LSlog_staticLoggerClass {
       );
 
       foreach ($list as $key => $id) {
-        $retval['list'][]=new LSsearchEntry($this,$this -> LSobject,$this -> params,$this -> _hash,$this -> result['list'],$id);
+        $retval['list'][] = new LSsearchEntry(
+          $this,
+          $this -> LSobject,
+          $this -> params,
+          $this -> result['list'],
+          $id
+        );
       }
     }
     return $retval;
@@ -1051,7 +1102,13 @@ class LSsearch extends LSlog_staticLoggerClass {
       $sortTable=$this -> getSortTable();
 
       foreach ($sortTable as $key => $id) {
-        $retval[]=new LSsearchEntry($this,$this -> LSobject,$this -> params,$this -> _hash,$this -> result['list'],$id);
+        $retval[] = new LSsearchEntry(
+          $this,
+          $this -> LSobject,
+          $this -> params,
+          $this -> result['list'],
+          $id
+        );
       }
     }
     return $retval;
@@ -1149,6 +1206,9 @@ class LSsearch extends LSlog_staticLoggerClass {
         return $ret;
       }
     }
+    elseif ($key == 'hash') {
+      return $this -> getHash();
+    }
     else {
       throw new Exception('Incorrect property !');
     }
@@ -1171,9 +1231,9 @@ class LSsearch extends LSlog_staticLoggerClass {
     else {
       $dir = -1;
     }
-    $oa = new LSsearchEntry($this,$this -> LSobject,$this -> params,$this -> _hash,$this -> result['list'],$a);
+    $oa = new LSsearchEntry($this, $this -> LSobject, $this -> params, $this -> result['list'], $a);
     $va = $oa->$sortBy;
-    $ob = new LSsearchEntry($this,$this -> LSobject,$this -> params,$this -> _hash,$this -> result['list'],$b);
+    $ob = new LSsearchEntry($this, $this -> LSobject, $this -> params, $this -> result['list'], $b);
     $vb = $ob->$sortBy;
 
     if ($va == $vb) return 0;
@@ -1212,7 +1272,7 @@ class LSsearch extends LSlog_staticLoggerClass {
    **/
   private function doSort() {
     if (!$this -> sort) {
-      self :: log_debug('doSort : sort is disabled');
+      self :: log_debug('doSort(): sort is disabled');
       return true;
     }
     if (is_null($this -> params['sortBy'])) {
@@ -1227,11 +1287,11 @@ class LSsearch extends LSlog_staticLoggerClass {
     }
 
     if (isset($this -> result['sort'][$this -> params['sortBy']][$this -> params['sortDirection']])) {
-      self :: log_debug('doSort : from cache');
+      self :: log_debug('doSort(): from cache');
       return true;
     }
 
-    self :: log_debug('doSort : '.$this -> params['sortBy'].' - '.$this -> params['sortDirection']);
+    self :: log_debug('doSort(): sort by "'.$this -> params['sortBy'].'" (order: '.$this -> params['sortDirection']).")";
 
     $this -> result['sort'][$this -> params['sortBy']][$this -> params['sortDirection']]=range(0,($this -> total-1));
 
@@ -1278,11 +1338,17 @@ class LSsearch extends LSlog_staticLoggerClass {
     $retval=array();
 
     if ($this -> total>0) {
-      $sortTable=$this -> getSortTable();
+      $sortTable = $this -> getSortTable();
 
       foreach ($sortTable as $key => $id) {
-        $entry=new LSsearchEntry($this,$this -> LSobject,$this -> params,$this -> _hash,$this -> result['list'],$id);
-        $retval[$entry->dn]=$entry->displayName;
+        $entry = new LSsearchEntry(
+          $this,
+          $this -> LSobject,
+          $this -> params,
+          $this -> result['list'],
+          $id
+        );
+        $retval[$entry -> dn] = $entry -> displayName;
       }
     }
 
@@ -1642,55 +1708,55 @@ class LSsearch extends LSlog_staticLoggerClass {
  * Error Codes
  **/
 LSerror :: defineError('LSsearch_01',
-_("LSsearch : Invalid filter : %{filter}.")
+___("LSsearch : Invalid filter : %{filter}.")
 );
 LSerror :: defineError('LSsearch_02',
-_("LSsearch : Invalid basedn : %{basedn}.")
+___("LSsearch : Invalid basedn : %{basedn}.")
 );
 LSerror :: defineError('LSsearch_03',
-_("LSsearch : Invalid value for %{param} parameter.")
+___("LSsearch : Invalid value for %{param} parameter.")
 );
 LSerror :: defineError('LSsearch_04',
-_("LSsearch : Invalid size limit. Must be an integer greater or equal to 0.")
+___("LSsearch : Invalid size limit. Must be an integer greater or equal to 0.")
 );
 LSerror :: defineError('LSsearch_05',
-_("LSsearch : Invalid parameter %{attr}. Must be an boolean.")
+___("LSsearch : Invalid parameter %{attr}. Must be an boolean.")
 );
 LSerror :: defineError('LSsearch_06',
-_("LSsearch : Invalid parameter attributes. Must be an string or an array of strings.")
+___("LSsearch : Invalid parameter attributes. Must be an string or an array of strings.")
 );
 LSerror :: defineError('LSsearch_07',
-_("LSsearch : Can't build attributes list for make filter.")
+___("LSsearch : Can't build attributes list for make filter.")
 );
 LSerror :: defineError('LSsearch_08',
-_("LSsearch : Error building filter with attribute '%{attr}' and pattern '%{pattern}'")
+___("LSsearch : Error building filter with attribute '%{attr}' and pattern '%{pattern}'")
 );
 LSerror :: defineError('LSsearch_09',
-_("LSsearch : Error combining filters.")
+___("LSsearch : Error combining filters.")
 );
 LSerror :: defineError('LSsearch_10',
-_("LSsearch : Invalid pattern.")
+___("LSsearch : Invalid pattern.")
 );
 LSerror :: defineError('LSsearch_11',
-_("LSsearch : Invalid attribute %{attr} in parameters.")
+___("LSsearch : Invalid attribute %{attr} in parameters.")
 );
 LSerror :: defineError('LSsearch_12',
-_("LSsearch : Error during the search.")
+___("LSsearch : Error during the search.")
 );
 LSerror :: defineError('LSsearch_13',
-_("LSsearch : Error sorting the search.")
+___("LSsearch : Error sorting the search.")
 );
 LSerror :: defineError('LSsearch_14',
-_("LSsearch : The function of the custum information %{name} is not callable.")
+___("LSsearch : The function of the custum information %{name} is not callable.")
 );
 LSerror :: defineError('LSsearch_15',
-_("LSsearch : Invalid predefinedFilter for LSobject type %{type} : %{label} (filter : %{filter}).")
+___("LSsearch : Invalid predefinedFilter for LSobject type %{type} : %{label} (filter : %{filter}).")
 );
 LSerror :: defineError('LSsearch_16',
-_("LSsearch : Error during execution of the custom action %{customAction}.")
+___("LSsearch : Error during execution of the custom action %{customAction}.")
 );
 LSerror :: defineError('LSsearch_17',
-_("LSsearch : Invalid search pattern.")
+___("LSsearch : Invalid search pattern.")
 );
 
 // LScli
