@@ -151,33 +151,33 @@ class LSsession {
     $path = ($external?'':LS_ROOT_DIR."/").$file;
     $local_path = ($external?'':LS_ROOT_DIR."/").LS_LOCAL_DIR.$file;
     $path = (file_exists($local_path)?$local_path:$path);
-    if ($path[0] != '/') {
+    if (!isAbsolutePath($path)) {
       $found = stream_resolve_include_path($path);
       if ($found === false) {
-        if (!$warn)
-          return false;
-        $log_msg = "includeFile($file, external=$external) : file $path not found in include path.";
-        if (class_exists('LSlog'))
-          self :: log_warning($log_msg);
-        else
-          error_log($log_msg);
+        self :: log(
+          ($warn?'WARNING':'TRACE'),
+          "includeFile($file, external=$external) : file $path not found in include path."
+        );
         return false;
       }
       else {
+        self :: log_trace("includeFile($file, external=$external): file path found using include path => '$found'");
         $path = $found;
       }
     }
     else if (!file_exists($path)) {
-      if (!$warn)
-        return false;
-      $log_msg = "includeFile($file, external=$external) : file not found ($local_path / $path)";
-      if (class_exists('LSlog'))
-        self :: log_warning($log_msg);
-      else
-        error_log($log_msg);
+      self :: log(
+        ($warn?'WARNING':'TRACE'),
+        "includeFile($file, external=$external): file not found ($local_path / $path)"
+      );
       return false;
     }
-    return include_once($path);
+    if (!include_once($path)) {
+      // Always log as warning in this case
+      self :: log_warning("includeFile($file, external=$external): include_once($path) not returned TRUE");
+      return false;
+    }
+    return true;
   }
 
  /**
@@ -445,43 +445,52 @@ class LSsession {
     if(class_exists($object)) {
       return true;
     }
-    $error = 0;
-    self :: loadLSclass('LSldapObject');
-    if (!self :: loadLSclass($object,'LSobjects')) {
-      self :: log_error("loadLSobject($object): Fail to load LSldapObject class");
-      $error = 1;
+    $error = false;
+    // Load LSldapObject class
+    if (!self :: loadLSclass('LSldapObject')) {
+      self :: log_error("loadLSobject($object): fail to load LSldapObject class");
+      $error = true;
     }
-    if (!self :: includeFile( LS_OBJECTS_DIR . 'config.LSobjects.'.$object.'.php' )) {
+    // Check LSobject type name
+    elseif (!LSldapObject :: isValidTypeName($object)) {
+      self :: log_error("loadLSobject($object): invalid LSobject type name");
+      $error = true;
+    }
+    // Load config file
+    elseif (!self :: includeFile( LS_OBJECTS_DIR . 'config.LSobjects.'.$object.'.php' ) || !isset($GLOBALS['LSobjects'][$object])) {
       self :: log_error("loadLSobject($object): Fail to include 'config.LSobjects.$object.php' file");
-      $error = 1;
+      $error = true;
     }
-    else {
-      if (!LSconfig :: set("LSobjects.$object",$GLOBALS['LSobjects'][$object])) {
-        self :: log_error("loadLSobject($object): Fail to LSconfig :: set('LSobjects.$object', \$GLOBALS['LSobjects'][$object])");
-        $error = 1;
-      }
-      else if (isset($GLOBALS['LSobjects'][$object]['LSaddons'])){
-        if (is_array($GLOBALS['LSobjects'][$object]['LSaddons'])) {
-          foreach ($GLOBALS['LSobjects'][$object]['LSaddons'] as $addon) {
-            if (!self :: loadLSaddon($addon)) {
-              self :: log_error("loadLSobject($object): Fail to load LSaddon '$addon'");
-              $error = 1;
-            }
-          }
-        }
-        else {
-          if (!self :: loadLSaddon($GLOBALS['LSobjects'][$object]['LSaddons'])) {
-            self :: log_error("loadLSobject($object): Fail to load LSaddon '".$GLOBALS['LSobjects'][$object]['LSaddons']."'");
-            $error = 1;
-          }
+    // Check config file
+    elseif (!isset($GLOBALS['LSobjects'][$object]) || !is_array($GLOBALS['LSobjects'][$object])) {
+      self :: log_error("loadLSobject($object): \$GLOBALS['LSobjects'][$object] is not declared after loaded config file (or is not an array).");
+      $error = true;
+    }
+    // Set LSobject type configuration
+    elseif (!LSconfig :: set("LSobjects.$object", $GLOBALS['LSobjects'][$object])) {
+      self :: log_error("loadLSobject($object): Fail to LSconfig :: set('LSobjects.$object', \$GLOBALS['LSobjects'][$object])");
+      $error = true;
+    }
+    // Load LSaddons used by this LSobject type (if configured)
+    else if (isset($GLOBALS['LSobjects'][$object]['LSaddons'])) {
+      if (!is_array($GLOBALS['LSobjects'][$object]['LSaddons']))
+        $GLOBALS['LSobjects'][$object]['LSaddons'] = array($GLOBALS['LSobjects'][$object]['LSaddons']);
+      foreach ($GLOBALS['LSobjects'][$object]['LSaddons'] as $addon) {
+        if (!self :: loadLSaddon($addon)) {
+          self :: log_error("loadLSobject($object): Fail to load LSaddon '$addon'");
+          $error = true;
         }
       }
     }
-    if ($error && $warn) {
-      LSerror :: addErrorCode('LSsession_04',$object);
-      return;
+    // Load or declare corresponding PHP class (if no previous error occured)
+    if (!$error && !self :: loadLSclass($object, 'LSobjects')) {
+      self :: log_debug("loadLSobject($object): Fail to load $object class. Implement simple one.");
+      eval("class $object extends LSldapObject {};");
     }
-    return true;
+    // Warn on error (is enabled)
+    if ($error && $warn)
+      LSerror :: addErrorCode('LSsession_04', $object);
+    return !$error;
   }
 
  /**
@@ -1828,76 +1837,111 @@ class LSsession {
    * @retval boolean True si le chargement Ã  rÃ©ussi, false sinon.
    **/
   private static function loadLSprofiles() {
-    if (is_array(self :: $ldapServer['LSprofiles'])) {
-      foreach (self :: $ldapServer['LSprofiles'] as $profile => $profileInfos) {
-        if (is_array($profileInfos)) {
-          foreach ($profileInfos as $topDn => $rightsInfos) {
-            // Do not handle 'label' key as a topDn
-            if ($topDn == 'label') {
-              continue;
-            }
-            /*
-             * If $topDn == 'LSobject', we search for each LSobject type to find
-             * all items on witch the user will have powers.
-             */
-            elseif ($topDn == 'LSobjects') {
-              if (is_array($rightsInfos)) {
-                foreach ($rightsInfos as $LSobject => $listInfos) {
-                  self :: log_debug('loadLSprofiles(): loading LSprofile ' . $profile . ' for LSobject ' . $LSobject . ' with params ' . var_export($listInfos, true));
-                  self :: loadLSprofilesLSobjects($profile, $LSobject, $listInfos);
-                }
-              }
-              else {
-                self :: log_warning('loadLSprofiles(): LSobjects => [] must be an array');
-              }
-            }
-            else {
-              if (is_array($rightsInfos)) {
-                foreach($rightsInfos as $dn => $conf) {
-                  if ((isset($conf['attr'])) && (isset($conf['LSobject']))) {
-                    if( self :: loadLSobject($conf['LSobject']) ) {
-                      if ($object = new $conf['LSobject']()) {
-                        if ($object -> loadData($dn)) {
-                          $listDns=$object -> getValue($conf['attr']);
-                          $valKey = (isset($conf['attr_value']))?$conf['attr_value']:'%{dn}';
-                          $val = self :: getLSuserObject() -> getFData($valKey);
-                          if (is_array($listDns)) {
-                            if (in_array($val,$listDns)) {
-                              self :: $LSprofiles[$profile][] = $topDn;
-                            }
-                          }
-                        }
-                        else {
-                          self :: log_warning("loadLSprofiles(): fail to load DN '$dn'.");
-                        }
-                      }
-                      else {
-                        self :: log_warning("loadLSprofiles(): fail to instanciate LSobject type '".$conf['LSobject']."'.");
-                      }
-                    }
-                  }
-                  else {
-                    if (self :: $dn == $dn) {
-                      self :: $LSprofiles[$profile][] = $topDn;
-                    }
-                  }
-                }
-              }
-              else {
-                if ( self :: $dn == $rightsInfos ) {
-                  self :: $LSprofiles[$profile][] = $topDn;
-                }
-              }
-            } // fin else ($topDn == 'LSobjects')
-          } // fin foreach($profileInfos)
-        } // fin is_array($profileInfos)
-      } // fin foreach LSprofiles
-      self :: log_debug("loadLSprofiles(): LSprofiles = ".print_r(self :: $LSprofiles,1));
-      return true;
-    }
-    else {
+    if (!is_array(self :: $ldapServer['LSprofiles'])) {
+      self :: log_warning('loadLSprofiles(): Current LDAP server have no configured LSprofile.');
       return;
     }
+    self :: log_trace("loadLSprofiles(): Current LDAP server LSprofile configuration: ".varDump(self :: $ldapServer['LSprofiles']));
+    foreach (self :: $ldapServer['LSprofiles'] as $profile => $profileInfos) {
+      if (!is_array($profileInfos)) {
+        self :: log_warning("loadLSprofiles(): Invalid configuration for LSprofile '$profile' (must be an array).");
+        continue;
+      }
+      foreach ($profileInfos as $topDn => $rightsInfos) {
+        // Do not handle 'label' key as a topDn
+        if ($topDn == 'label') {
+          continue;
+        }
+        elseif ($topDn == 'LSobjects') {
+          /*
+           * If $topDn == 'LSobject', we search for each LSobject type to find
+           * all items on witch the user will have powers.
+           */
+          if (!is_array($rightsInfos)) {
+            self :: log_warning('loadLSprofiles(): LSobjects => [] must be an array');
+            continue;
+          }
+          foreach ($rightsInfos as $LSobject => $listInfos) {
+            self :: log_debug('loadLSprofiles(): loading LSprofile ' . $profile . ' for LSobject ' . $LSobject . ' with params ' . var_export($listInfos, true));
+            self :: loadLSprofilesLSobjects($profile, $LSobject, $listInfos);
+          }
+        }
+        else {
+          /*
+           * Otherwise, we are normally in case of $topDn == a base DN and
+           * $rightsInfos is :
+           *   - an array (see above)
+           *   - a user DN
+           */
+          if (is_array($rightsInfos)) {
+            /*
+             * $rightsInfos is an array, so we could have :
+             *  - users DNs as key and null as value
+             *  - DN of an object as key and an array of parameters to list users from one
+             *    of its attribute as value
+             */
+            foreach($rightsInfos as $dn => $conf) {
+              if (is_array($conf) && isset($conf['attr']) && isset($conf['LSobject'])) {
+                // We have to retreive this LSobject and list one of its attribute to retreive
+                // users key info.
+                if(!self :: loadLSobject($conf['LSobject'])) {
+                  // Warning log message is already emited by self :: loadLSobject()
+                  continue;
+                }
+
+                // Instanciate object and retreive its data
+                $object = new $conf['LSobject']();
+                if (!$object -> loadData($dn)) {
+                  self :: log_warning("loadLSprofiles(): fail to load DN '$dn'.");
+                  continue;
+                }
+
+                // Retreive users key info values from object attribute
+                $list_users_key_values = $object -> getValue($conf['attr']);
+                if (!is_array($list_users_key_values)) {
+                  self :: log_warning("loadLSprofiles(): fail to retreive values of attribute '".$conf['attr']."' of LSobject ".$conf['LSobject']." with DN='$dn'");
+                  continue;
+                }
+                self :: log_trace("loadLSprofiles(): retreived values of attribute '".$conf['attr']."' of LSobject ".$conf['LSobject']." with DN='$dn': '".implode("', '", $list_users_key_values)."'");
+
+                // Retreive current connected key value
+                $user_key_value_format = (isset($conf['attr_value'])?$conf['attr_value']:'%{dn}');
+                $user_key_value = self :: getLSuserObject() -> getFData($user_key_value_format);
+
+                // Check current connected user is list in attribute values
+                if (in_array($user_key_value, $list_users_key_values)) {
+                  self :: log_trace("loadLSprofiles(): current connected user is present in attribute '".$conf['attr']."' of LSobject ".$conf['LSobject']." with DN='$dn' (user key value: '$user_key_value')");
+                  self :: $LSprofiles[$profile][] = $topDn;
+                }
+                else
+                  self :: log_trace("loadLSprofiles(): current connected user is not list in attribute '".$conf['attr']."' of LSobject ".$conf['LSobject']." with DN='$dn' (user key value: '$user_key_value')");
+              }
+              else {
+                // $conf is not an array, users DNs could be the key $dn and we don't care
+                // about $conf value (normally null)
+                if (self :: $dn == $dn) {
+                  self :: log_trace("loadLSprofiles(): current connected user DN is explicitly list in $profile LSprofile configuration");
+                  self :: $LSprofiles[$profile][] = $topDn;
+                }
+                else
+                  self :: log_trace("loadLSprofiles(): current connected user DN is NOT explicitly list in $profile LSprofile configuration");
+              }
+            }
+          }
+          else {
+            // $rightsInfos is not an array => its could be a user DN
+            if ( self :: $dn == $rightsInfos ) {
+              self :: log_trace("loadLSprofiles(): current connected user DN is explicitly appointed as $profile LSprofile in configuration");
+              self :: $LSprofiles[$profile][] = $topDn;
+            }
+            else
+              self :: log_trace("loadLSprofiles(): current connected user DN is NOT explicitly appointed as $profile LSprofile in configuration");
+          }
+        } // fin else ($topDn == 'LSobjects' or 'label')
+      } // fin foreach($profileInfos)
+    } // fin foreach LSprofiles
+    self :: log_debug("loadLSprofiles(): LSprofiles = ".print_r(self :: $LSprofiles,1));
+    return true;
   }
 
   /**
@@ -2745,85 +2789,83 @@ class LSsession {
      * Error Codes
      */
     LSerror :: defineError('LSsession_01',
-    _("LSsession : The constant %{const} is not defined.")
+    ___("LSsession : The constant '%{const}' is not defined.")
     );
     LSerror :: defineError('LSsession_02',
-    _("LSsession : The %{addon} support is uncertain. Verify system compatibility and the add-on configuration.")
+    ___("LSsession : The addon '%{addon}' support is uncertain. Verify system compatibility and the add-on configuration.")
     );
     LSerror :: defineError('LSsession_03',
-    _("LSsession : LDAP server's configuration data are invalid. Can't connect.")
+    ___("LSsession : LDAP server's configuration data are invalid. Can't connect.")
     );
     LSerror :: defineError('LSsession_04',
-    _("LSsession : Failed to load LSobject type %{type} : unknon type.")
+    ___("LSsession : Failed to load LSobject type '%{type}' : unknon type.")
     );
     LSerror :: defineError('LSsession_05',
-    _("LSsession : Failed to load LSclass %{class}.")
+    ___("LSsession : Failed to load LSclass '%{class}'.")
     );
     LSerror :: defineError('LSsession_06',
-    _("LSsession : Login or password incorrect.")
+    ___("LSsession : Login or password incorrect.")
     );
     LSerror :: defineError('LSsession_07',
-    _("LSsession : Impossible to identify you : Duplication of identities.")
+    ___("LSsession : Impossible to identify you : Duplication of identities.")
     );
     LSerror :: defineError('LSsession_08',
-    _("LSsession : Can't load class of authentification (%{class}).")
+    ___("LSsession : Can't load class of authentification (%{class}).")
     );
     LSerror :: defineError('LSsession_09',
-    _("LSsession : Can't connect to LDAP server.")
+    ___("LSsession : Can't connect to LDAP server.")
     );
     LSerror :: defineError('LSsession_10',
-    _("LSsession : Impossible to authenticate you.")
+    ___("LSsession : Impossible to authenticate you.")
     );
     LSerror :: defineError('LSsession_11',
-    _("LSsession : Your are not authorized to do this action.")
+    ___("LSsession : Your are not authorized to do this action.")
     );
     LSerror :: defineError('LSsession_12',
-    _("LSsession : Some informations are missing to display this page.")
+    ___("LSsession : Some informations are missing to display this page.")
     );
     LSerror :: defineError('LSsession_13',
-    _("LSsession : The function of the custom action %{name} does not exists or is not configured.")
+    ___("LSsession : The function of the custom action '%{name}' does not exists or is not configured.")
     );
     LSerror :: defineError('LSsession_14',
-    _("LSsession : Fail to retreive user's LDAP credentials from LSauth.")
+    ___("LSsession : Fail to retreive user's LDAP credentials from LSauth.")
     );
     LSerror :: defineError('LSsession_15',
-    _("LSsession : Fail to reconnect to LDAP server with user's LDAP credentials.")
+    ___("LSsession : Fail to reconnect to LDAP server with user's LDAP credentials.")
     );
     LSerror :: defineError('LSsession_16',
-    _("LSsession : No import/export format define for this object type.")
+    ___("LSsession : No import/export format define for this object type.")
     );
     LSerror :: defineError('LSsession_17',
-    _("LSsession : Error during creation of list of levels. Contact administrators. (Code : %{code})")
+    ___("LSsession : Error during creation of list of levels. Contact administrators. (Code : %{code})")
     );
     LSerror :: defineError('LSsession_18',
-    _("LSsession : The password recovery is disabled for this LDAP server.")
+    ___("LSsession : The password recovery is disabled for this LDAP server.")
     );
     LSerror :: defineError('LSsession_19',
-    _("LSsession : Some informations are missing to recover your password. Contact administrators.")
+    ___("LSsession : Some informations are missing to recover your password. Contact administrators.")
     );
     LSerror :: defineError('LSsession_20',
-    _("LSsession : Error during password recovery. Contact administrators.(Step : %{step})")
+    ___("LSsession : Error during password recovery. Contact administrators.(Step : %{step})")
     );
     LSerror :: defineError('LSsession_21',
-    _("LSsession : call function %{func} do not provided from LSaddon %{addon}.")
-    );
-    LSerror :: defineError('LSsession_22',
-    _("LSsession : problem during initialisation.")
+    ___("LSsession : The function '%{func}' configured for the view '%{view}' of the LSaddon '%{addon}' is not declared in the LSaddon file.")
     );
+    // LSsession_22: Not used
     LSerror :: defineError('LSsession_23',
-    _("LSsession : view function %{func} for LSaddon %{addon} doet not exist.")
+    ___("LSsession : The function '%{func}' configured for the view '%{view}' of the LSaddon '%{addon}' doesn't exist.")
     );
     LSerror :: defineError('LSsession_24',
-    _("LSsession : invalid related object's DN pass in parameter.")
+    ___("LSsession : invalid related object's DN pass in parameter.")
     );
     LSerror :: defineError('LSsession_25',
-    _("LSsession : the LSaddon %{addon} keep using old-style addon view URL. Please upgrade it.")
+    ___("LSsession : the LSaddon %{addon} keep using old-style addon view URL. Please upgrade it.")
     );
     LSerror :: defineError('LSsession_26',
-    _("LSsession : You have been redirect from an old-style URL %{url}. Please upgrade this link.")
+    ___("LSsession : You have been redirect from an old-style URL %{url}. Please upgrade this link.")
     );
     LSerror :: defineError('LSsession_27',
-    _("LSsession : You always seem to use %{old} in your custom code: Please upgrade it and use %{new}.<pre>\nContext:\n%{context}</pre>")
+    ___("LSsession : You always seem to use %{old} in your custom code: Please upgrade it and use %{new}.<pre>\nContext:\n%{context}</pre>")
     );
   }
 
@@ -2897,11 +2939,25 @@ class LSsession {
         return True;
       }
       else {
-        LSerror :: addErrorCode('LSsession_21',array('func' => $func -> getName(),'addon' => $addon));
+        LSerror :: addErrorCode(
+          'LSsession_21',
+          array(
+            'func' => $func -> getName(),
+            'addon' => $addon,
+            'view' => $viewId,
+          )
+        );
       }
     }
     else {
-      LSerror :: addErrorCode('LSsession_23',array('func' => $viewFunction,'addon' => $LSaddon));
+      LSerror :: addErrorCode(
+        'LSsession_23',
+        array(
+          'func' => $viewFunction,
+          'addon' => $addon,
+          'view' => $viewId,
+        )
+      );
     }
     return False;
   }
