@@ -237,7 +237,7 @@ class LStemplate extends LSlog_staticLoggerClass {
   * @retval string The path of the image file
   **/
   public static function getImagePath($image, $with_nocache=false) {
-    $exts=array('png','gif','jpg');
+    $exts=array('svg', 'png', 'gif', 'jpg');
     foreach($exts as $ext) {
       $path = self :: getFilePath("$image.$ext", self :: $config['image_dir'], False, $with_nocache);
       if ($path) return $path;
@@ -654,11 +654,11 @@ function LStemplate_smarty_var_dump($params, &$smarty) {
 
 // Errors
 LSerror :: defineError('LStemplate_01',
-_("LStemplate : Template %{file} not found.")
+___("LStemplate : Template %{file} not found.")
 );
 LSerror :: defineError('LStemplate_02',
-_("LStemplate : Fail to execute trigger %{callable} on event %{event} : is not callable.")
+___("LStemplate : Fail to execute trigger %{callable} on event %{event} : is not callable.")
 );
 LSerror :: defineError('LStemplate_03',
-_("LStemplate : Error during the execution of the trigger %{callable} on event %{event}.")
+___("LStemplate : Error during the execution of the trigger %{callable} on event %{event}.")
 );
