@@ -669,6 +669,31 @@ function LSdebugDefined() {
     return "unknown : ".(string)$callable;
   }
 
+/**
+ * Check if a path is absolute
+ *
+ * @param[in] $path string The path
+ *
+ * @retval boolean True if path is absolute, False otherwise
+ */
+function isAbsolutePath($path) {
+  return strStartWith($path, '/') || strStartWith($path, './') || strStartWith($path, '../');
+}
+
+/**
+ * Check if a string start with another specified string
+ *
+ * @param[in] $string string The string to search in
+ * @param[in] $start_string string The starting string to check
+ *
+ * @retval boolean True if string start by specified one, False otherwise
+ */
+function strStartWith($string, $start_string) {
+  if (strlen($start_string) > strlen($string))
+    return false;
+  return substr($string, 0, strlen($start_string)) === $start_string;
+}
+
 /**
  * Dump file content
  *
@@ -722,3 +747,38 @@ function dumpFile($file_path, $mime_type=null, $max_age=3600, $force_download=fa
     exit();
   }
 }
+
+/**
+ * Format a callable object for logging
+ * @param  callable $callable The callable object
+ * @return string The callable object string representation
+ */
+function format_callable($callable) {
+        if (is_array($callable))
+                if (is_string($callable[0]))
+                        return $callable[0]."::".$callable[1]."()";
+                elseif (is_object($callable[0]))
+                        return get_class($callable[0])."->".$callable[1]."()";
+                else
+                        return "Unkown->".$callable[1]."()";
+        else
+                return $callable."()";
+}
+
+function is_empty($val) {
+  switch(gettype($val)) {
+    case "boolean":
+    case "integer":
+    case "double":
+    case "object":
+    case "resource":
+            return False;
+    case "array":
+    case "string":
+      if ($val == "0") return false;
+      return empty($val);
+    case "NULL":
+      return True;
+  }
+  return empty($val);
+}
