@@ -110,9 +110,19 @@ LSurl :: add_handler('#^ajax/(?P<type>class|addon)/(?P<type_value>[^/]+)/(?P<act
  **/
 function handle_old_index_ajax_php($request) {
   LSerror :: addErrorCode('LSsession_26', 'index_ajax.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => 'Redirection unsupported',
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSsession :: displayAjaxReturn(null);
 }
-LSurl :: add_handler('#^index_ajax\.php#', 'handle_old_index_ajax_php');
+LSurl :: add_handler('#^index_ajax\.php#', 'handle_old_index_ajax_php', false);
 
 /*
  * Handle global seearch request
@@ -229,9 +239,19 @@ function handle_old_global_search_php($request) {
       $url .= "&refresh";
   }
   LSerror :: addErrorCode('LSsession_26', 'global_search.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^global_search\.php#', 'handle_old_global_search_php');
+LSurl :: add_handler('#^global_search\.php#', 'handle_old_global_search_php', false);
 
 /*
  * Handle static file request
@@ -605,9 +625,19 @@ function handle_old_custom_search_action_php($request) {
   else
     $url = "object/".$_GET['LSobject']."/customAction/".$_GET['customAction'];
   LSerror :: addErrorCode('LSsession_26', 'custom_search_action.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^custom_search_action\.php#', 'handle_old_custom_search_action_php');
+LSurl :: add_handler('#^custom_search_action\.php#', 'handle_old_custom_search_action_php', false);
 
 /*
  * Handle LSobject select request
@@ -711,9 +741,19 @@ function handle_old_select_php($request) {
     $url = "object/".$_GET['LSobject'];
   }
   LSerror :: addErrorCode('LSsession_26', 'select.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'LSobject parameter is missing to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^select\.php#', 'handle_old_select_php');
+LSurl :: add_handler('#^select\.php#', 'handle_old_select_php', false);
 
 /*
  * Handle LSobject import request
@@ -773,9 +813,19 @@ function handle_old_import_php($request) {
   else
     $url = "object/".$_GET['LSobject']."/import";
   LSerror :: addErrorCode('LSsession_26', 'import.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^import\.php#', 'handle_old_import_php');
+LSurl :: add_handler('#^import\.php#', 'handle_old_import_php', false);
 
 /*
  * Handle LSobject create request
@@ -805,14 +855,19 @@ function handle_LSobject_create($request) {
         if ($obj -> loadData(urldecode($_GET['relatedLSobjectDN']))) {
           if (LSrelation :: exists($_GET['relatedLSobject'], $_GET['LSrelation'])) {
             $relation = new LSrelation($obj, $_GET['LSrelation']);
-            $attr = $relation -> relatedEditableAttribute;
-            if (isset($object -> attrs[$attr])) {
-              $value = $relation -> getRelatedKeyValue();
-              if (is_array($value)) $value=$value[0];
-              $object -> attrs[$attr] -> data = array($value);
+            if ($relation -> correctly_configured) {
+              $attr = $relation -> relatedEditableAttribute;
+              if (isset($object -> attrs[$attr])) {
+                $value = $relation -> getRelatedKeyValue();
+                if (is_array($value)) $value=$value[0];
+                $object -> attrs[$attr] -> data = array($value);
+              }
+              else {
+                LSerror :: addErrorCode('LSrelation_06',array('relation' => $relation -> getName(),'LSobject' => $obj -> getType()));
+              }
             }
             else {
-              LSerror :: addErrorCode('LSrelations_06',array('relation' => $relation -> getName(),'LSobject' => $obj -> getType()));
+              LSlog :: warning("Relation '".$_GET['LSrelation']."' of object type '".$_GET['relatedLSobject']."' is not correctly configured.");
             }
           }
           else {
@@ -896,9 +951,19 @@ function handle_old_create_php($request) {
   else
     $url = "object/".$_GET['LSobject']."/create";
   LSerror :: addErrorCode('LSsession_26', 'create.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^create\.php#', 'handle_old_create_php');
+LSurl :: add_handler('#^create\.php#', 'handle_old_create_php', false);
 
 /*
  * Handle LSobject show request
@@ -992,9 +1057,19 @@ function handle_old_view_php($request) {
   else
     $url = "object/".$_GET['LSobject'];
   LSerror :: addErrorCode('LSsession_26', 'view.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^view\.php#', 'handle_old_view_php');
+LSurl :: add_handler('#^view\.php#', 'handle_old_view_php', false);
 
 /*
  * Handle LSobject modify request
@@ -1027,14 +1102,14 @@ function handle_LSobject_modify($request) {
       if (isset($_REQUEST['ajax'])) {
         LSsession :: displayAjaxReturn (
           array(
-            'LSredirect' => "object/$LSobject/".$object -> getDn()
+            'LSredirect' => "object/$LSobject/".urlencode($object -> getDn())
           )
         );
         return true;
       }
       else {
         if (!LSdebugDefined()) {
-          LSurl :: redirect("object/$LSobject/".$object -> getDn());
+          LSurl :: redirect("object/$LSobject/".urlencode($object -> getDn()));
         }
       }
     }
@@ -1100,9 +1175,19 @@ function handle_old_modify_php($request) {
   else
     $url = "object/".$_GET['LSobject']."/".$_GET['dn']."/modify";
   LSerror :: addErrorCode('LSsession_26', 'modify.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^modify\.php#', 'handle_old_modify_php');
+LSurl :: add_handler('#^modify\.php#', 'handle_old_modify_php', false);
 
 /*
  * Handle LSobject remove request
@@ -1180,9 +1265,19 @@ function handle_old_remove_php($request) {
   else
     $url = "object/".$_GET['LSobject']."/".$_GET['dn']."/remove";
   LSerror :: addErrorCode('LSsession_26', 'remove.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^remove\.php#', 'handle_old_remove_php');
+LSurl :: add_handler('#^remove\.php#', 'handle_old_remove_php', false);
 
 /*
  * Handle LSobject customAction request
@@ -1306,9 +1401,19 @@ function handle_old_custom_action_php($request) {
   else
     $url = "object/".$_GET['LSobject']."/".$_GET['dn']."/customAction/".$_GET['customAction'];
   LSerror :: addErrorCode('LSsession_26', 'custom_action.php');
+  LSlog :: warning(
+    getFData(
+      "Handling old URL style redirection:\n - Requested URL: '%{old}'\n - Redirection URL: '%{new}'\n - Referer: %{referer}",
+      array (
+        'old' => $request -> current_url,
+        'new' => ($url?$url:'missing parameter to compose URL'),
+        'referer' => ($request -> referer?"'".$request -> referer."'":'Unknown (direct access or hidden by web-browser)'),
+      )
+    )
+  );
   LSurl :: redirect($url);
 }
-LSurl :: add_handler('#^custom_action\.php#', 'handle_old_custom_action_php');
+LSurl :: add_handler('#^custom_action\.php#', 'handle_old_custom_action_php', false);
 
 /*
  ************************************************************
@@ -1351,4 +1456,4 @@ function handle_old_addon_view($request) {
  }
  LSurl :: redirect();
 }
-LSurl :: add_handler('#^addon_view\.php#', 'handle_old_addon_view');
+LSurl :: add_handler('#^addon_view\.php#', 'handle_old_addon_view', false);
