@@ -214,14 +214,14 @@ $GLOBALS['LSlog']['handlers'] = array (
 	array (
 		'handler' => 'file',
 		'path' => 'tmp/LS.log',
-    'loggers' => array('LSurl'),
+    //'loggers' => array('LSurl'),
 	),
 	array (
 		'handler' => 'file',
 		'path' => 'tmp/debug.log',
     'level' => 'TRACE',
-    //'loggers' => array('LSformElement_password'),
-    'excluded_loggers' => array('LSurl'),
+    'loggers' => array('LSformElement_date', 'LSldap'),
+    //'excluded_loggers' => array('LSsearch'),
     'enabled' => true,
 	),
 	/*array (
@@ -238,7 +238,7 @@ $GLOBALS['LSlog']['handlers'] = array (
 		'level' => 'ERROR',
 	),*/
 );
-$GLOBALS['LSlog']['level'] = 'DEBUG';
+$GLOBALS['LSlog']['level'] = 'WARNING';
 $GLOBALS['LSlog']['enable'] = true;
 
 define('NB_LSOBJECT_LIST',30);
